@@ -2093,7 +2093,7 @@ namespace IPod
 
         private string PlayCountsPath
         {
-            get { return ControlPath + "iTunes/Play Counts"; }
+            get { return ControlPath + "/iTunes/Play Counts"; }
         }
 
         internal string Name
@@ -2200,6 +2200,12 @@ namespace IPod
                 int entryLength = dbrec.ToInt32(header, 8);
                 int numEntries = dbrec.ToInt32(header, 12);
 
+                if (numEntries > tracks.Count)
+                {
+                    //invalid data
+                    return;
+                }
+
                 for (int i = 0; i < numEntries; i++)
                 {
 
@@ -2234,7 +2240,7 @@ namespace IPod
 
         private bool LoadOnTheGo(int num)
         {
-            string path = ControlPath + "iTunes/OTGPlaylistInfo";
+            string path = ControlPath + "/iTunes/OTGPlaylistInfo";
 
             if (num != 0)
             {
@@ -2510,6 +2516,9 @@ namespace IPod
                 {
                     throw new DatabaseWriteException(String.Format("File '{0}' for track '{1}' does not exist",
                                                                      track.FileName, track.Title));
+                } else if (track.Duration.Equals (TimeSpan.Zero)) {
+                    throw new DatabaseWriteException(String.Format("Track '{0}' has no Duration assigned",
+                                                                     track.Title));
                 }
             }
 
